@@ -10,7 +10,7 @@ use DateTime::Event::Recurrence;
 use English;
 use Error::Pure qw(err);
 
-our $VERSION = 0.10;
+our $VERSION = 0.11;
 
 # Constructor.
 sub new {
@@ -47,6 +47,7 @@ sub new {
 # Get DateTime object with random date.
 sub get {
 	my ($self, $date) = @_;
+
 	if ($self->{'year'}) {
 		if ($self->{'month'}) {
 			if ($self->{'day'}) {
@@ -89,29 +90,35 @@ sub get {
 			}
 		}
 	}
+
 	return $date;
 }
 
 # Random DateTime object for day.
 sub random {
 	my $self = shift;
+
 	my $daily = DateTime::Event::Recurrence->daily;
+
 	return $daily->next($self->_range);
 }
 
 # Random DateTime object for day defined by day.
 sub random_day {
 	my ($self, $day) = @_;
+
 	$self->_check_day($day);
 	my $monthly_day = DateTime::Event::Recurrence->monthly(
 		'days' => $day,
 	);
+
 	return $monthly_day->next($self->random);
 }
 
 # Random DateTime object for day defined by day and month.
 sub random_day_month {
 	my ($self, $day, $month) = @_;
+
 	$self->_check_day($day);
 	my $yearly_day_month = DateTime::Event::Recurrence->yearly(
 		'days' => $day,
@@ -121,12 +128,14 @@ sub random_day_month {
 	if (! defined $dt) {
 		err 'Cannot create DateTime object.';
 	}
+
 	return $dt;
 }
 
 # DateTime object for day defined by day, month and year.
 sub random_day_month_year {
 	my ($self, $day, $month, $year) = @_;
+
 	$self->_check_day($day);
 	my $dt = eval {
 		DateTime->new(
@@ -139,20 +148,23 @@ sub random_day_month_year {
 		err 'Cannot create DateTime object.',
 			'Error', $EVAL_ERROR;
 	}
+
 	return $dt;
 }
 
 # Random DateTime object for day defined by month.
 sub random_month {
 	my ($self, $month) = @_;
+
 	my $random_day = $self->_range;
+
 	return $self->random_month_year($month, $random_day->year);
 }
 
 # Random DateTime object for day defined by month and year.
 sub random_month_year {
 	my ($self, $month, $year) = @_;
-	my $daily = DateTime::Event::Recurrence->daily;
+
 	my $after = eval {
 		DateTime->new(
 			'day' => 1,
@@ -164,17 +176,11 @@ sub random_month_year {
 		err 'Cannot create DateTime object.',
 			'Error', $EVAL_ERROR;
 	}
-	my $before = eval {
-		DateTime->new(
-			'day' => 31,
-			'month' => $month,
-			'year' => $year,
-		);
-	};
-	if ($EVAL_ERROR) {
-		err 'Cannot create DateTime object.',
-			'Error', $EVAL_ERROR;
-	}
+
+	my $before = $after->clone;
+	$before->add(months => 1)->subtract(days => 1);
+
+	my $daily = DateTime::Event::Recurrence->daily;
 	return $daily->next(DateTime::Event::Random->datetime(
 		'after' => $after,
 		'before' => $before,
@@ -184,7 +190,9 @@ sub random_month_year {
 # Random DateTime object for day defined by year.
 sub random_year {
 	my ($self, $year) = @_;
+
 	my $daily = DateTime::Event::Recurrence->daily;
+
 	return $daily->next(DateTime::Event::Random->datetime(
 		'after' => DateTime->new(
 			'day' => 1,
@@ -202,6 +210,7 @@ sub random_year {
 # Check day.
 sub _check_day {
 	my ($self, $day) = @_;
+
 	if ($day !~ m/^\d+$/ms) {
 		err "Day isn't positive number.";
 	}
@@ -214,6 +223,7 @@ sub _check_day {
 # Random date in range.
 sub _range {
 	my $self = shift;
+
 	return DateTime::Event::Random->datetime(
 		'after' => $self->{'dt_from'},
 		'before' => $self->{'dt_to'},
@@ -431,12 +441,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2013-2021
+© 2013-2022 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.10
+0.11
 
 =cut
